package Data::Object::Func::Array;

use Data::Object 'Class';

extends 'Data::Object::Func';

# BUILD
# METHODS

1;

=encoding utf8

=head1 NAME

Data::Object::Func::Array

=cut

=head1 ABSTRACT

Functions for ArrayRefs

=cut

=head1 SYNOPSIS

  use Data::Object::Func::Array;

=cut

=head1 DESCRIPTION

Data::Object::Func::Array is an abstract base class for function classes in the
Data::Object::Func::Array space.

=cut
